# AUTOGENERATED! DO NOT EDIT! File to edit: 00_core.ipynb (unless otherwise specified).

__all__ = ['say_hello', 'say_hello2']

# Cell
def say_hello(to):
    "Say hello to somebody"
    return f'Hello: {to}!'

def say_hello2(to):
    "Say hello to somebody"
    return f'Hello: {to}!'