# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"say_hello": "00_core.ipynb",
         "say_hello2": "00_core.ipynb"}

modules = ["core.py"]

doc_url = "https://andrewm4894.github.io/am4894bq/"

git_url = "https://github.com/andrewm4894/am4894bq/tree/master/"

def custom_doc_links(name): return None
